#This R script is used in the Example 1: the Post-analysis of CNVs in a Human Dataset in HandyCNV Paper.
#
# Citation: Zhou J, Liu L, Lopdell TJ, Garrick DJ and Shi Y (2021). 
#           HandyCNV: Standardized Summary, Annotation, Comparison and Visualization of CNV, CNVR, and ROH. 
#           Front. Genet. 12:731355. doi: 10.3389/fgene.2021.731355
#
# Example data was cited from: 
#           Godoy VCSM de, Bellucco FT, Colovati M, Oliveira-Junior HR de, Moysés-Oliveira M, Melaragno MI. 
#           Copy number variation (CNV) identification, interpretation, and database from Brazilian patients.
#           Genet Mol Biol. 2020;43(4). doi:10.1590/1678-4685-gmb-2019-0218
#
#To run through this example,require to download the genotype data and install following packages
install.packages("remotes") #Skip this step if you had install this package before
remotes::install_github(repo = "JH-Zhou/HandyCNV@v1.1.6") #Skip this step if you had install this package before
library(HandyCNV)
library(dplyr)

# Setup the working directory in your computer
setwd("C:/localpath")

#Step 1. Read CNV lists from Godoy VCSM de's paper and prepare it as standard format
human_cnv_s <- read.csv(file = "human.csv", header = T, sep =",", fileEncoding = "UTF-8-BOM")%>%
               select(Sample_ID = Case, Chr = Chr, Start, End, CNV_Value = CN.State)

#Step.2 clean and brief summary of CNVs
clean_cnv <- cnv_clean(standard_cnv = human_cnv_s, drop_length = 5)

#Step.3 Take a quick look at the CNV distribution
chr_14 <- cnv_visual(clean_cnv, chr_id = 14, width_1 = 40)
cnv_visual(clean_cnv, chr_id = 14, start_position = 105, end_position = 110)

#Step.4 CNV Summary plot
cnv_summary_plot(clean_cnv, plot_sum_1 = T, plot_sum_2 = T)

#Step.5 Generate and brief summary of CNVRs
cnvr <- call_cnvr(clean_cnv, chr_set = 22)

#Step.6 Make CNVR distribution plot
cnvr_plot(cnvr, assembly = "hg19", left_prop_label = 3.5, legend_x = 200, width_1 = 25)

#Step.7 Download reference genome
get_refgene()
human_hg19 <- get_refgene("Human_hg19")

#Step.8 Annotate genes on CNV and CNVR
gene_frequency <- call_gene(refgene = human_hg19, interval = cnvr, clean_cnv = clean_cnv)

#Step.9 Plot high frequency CNVRs
cnvr_plot(cnvr, clean_cnv = clean_cnv, refgene = human_hg19, sample_size = 268, common_cnv_threshold = 0.2, col_gene = "red")

#Step.10 Extract Sample ID that contains interested Genes
sample_id <- get_samples(annotated_cnvlist = "call_gene/cnv_annotation.txt", gene_name = "ADAM6")

